@@ -164,9 +164,10 @@ class AdminClientABC(abc.ABC):
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
         with_user_info: Literal[True],
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         org_name: str | None = None,
     ) -> ClusterUserWithInfo:
         ...
@@ -177,21 +178,22 @@ class AdminClientABC(abc.ABC):
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
         with_user_info: Literal[False] = ...,
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         org_name: str | None = None,
     ) -> ClusterUser:
         ...
 
-    @abstractmethod
     async def create_cluster_user(
         self,
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         with_user_info: bool = False,
         org_name: str | None = None,
     ) -> ClusterUser | ClusterUserWithInfo:
@@ -425,6 +427,7 @@ class AdminClientABC(abc.ABC):
         balance: Balance = Balance(),
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
+        storage_size_mb: int | None = None,
     ) -> OrgCluster:
         ...
 
@@ -441,7 +444,7 @@ class AdminClientABC(abc.ABC):
         ...
 
     @abstractmethod
-    async def update_org_cluster(self, org_cluster: OrgCluster) -> OrgCluster:
+    async def update_org_cluster(self, org_cluster: OrgCluster) -> None:
         ...
 
     @abstractmethod
@@ -452,6 +455,16 @@ class AdminClientABC(abc.ABC):
     ) -> None:
         ...
 
+    @abstractmethod
+    async def update_org_cluster_defaults(
+        self,
+        cluster_name: str,
+        org_name: str,
+        default_quota: Quota = Quota(),
+        default_credits: Decimal | None = None,
+    ) -> OrgCluster:
+        ...
+
     @abstractmethod
     async def update_org_cluster_quota(
         self,
@@ -897,15 +910,30 @@ class AdminClientBase:
             raw_user = await resp.json()
             return self._parse_cluster_user(cluster_name, raw_user)
 
+    def _quota_to_payload(self, quota: Quota) -> dict[str, Any]:
+        res = {}
+        if quota.total_running_jobs is not None:
+            res["total_running_jobs"] = quota.total_running_jobs
+        return res
+
+    def _balance_to_payload(self, balance: Balance) -> dict[str, Any]:
+        res = {}
+        if balance.credits is not None:
+            res["credits"] = str(balance.credits)
+        if balance.spent_credits is not None:
+            res["spent_credits"] = str(balance.spent_credits)
+        return res
+
     @overload
     async def create_cluster_user(
         self,
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
         with_user_info: Literal[True],
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         org_name: str | None = None,
     ) -> ClusterUserWithInfo:
         ...
@@ -916,9 +944,10 @@ class AdminClientBase:
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
         with_user_info: Literal[False] = ...,
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         org_name: str | None = None,
     ) -> ClusterUser:
         ...
@@ -928,25 +957,19 @@ class AdminClientBase:
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         with_user_info: bool = False,
         org_name: str | None = None,
     ) -> ClusterUser | ClusterUserWithInfo:
-        payload: dict[str, Any] = {
-            "user_name": user_name,
-            "role": role.value,
-            "quota": {},
-            "balance": {},
-        }
+        payload: dict[str, Any] = {"user_name": user_name, "role": role.value}
         if org_name:
             payload["org_name"] = org_name
-        if quota.total_running_jobs is not None:
-            payload["quota"]["total_running_jobs"] = quota.total_running_jobs
-        if balance.credits is not None:
-            payload["balance"]["credits"] = str(balance.credits)
-        if balance.spent_credits is not None:
-            payload["balance"]["spent_credits"] = str(balance.spent_credits)
+        if quota:
+            payload["quota"] = self._quota_to_payload(quota)
+        if balance:
+            payload["balance"] = self._balance_to_payload(balance)
 
         async with self._request(
             "POST",
@@ -1319,6 +1342,7 @@ class AdminClientBase:
             if payload.get("default_credits")
             else None,
             default_quota=self._parse_quota(payload.get("default_quota")),
+            storage_size_mb=payload.get("storage_size_mb"),
         )
 
     async def create_org_cluster(
@@ -1329,6 +1353,7 @@ class AdminClientBase:
         balance: Balance = Balance(),
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
+        storage_size_mb: int | None = None,
     ) -> OrgCluster:
         payload: dict[str, Any] = {
             "org_name": org_name,
@@ -1348,6 +1373,8 @@ class AdminClientBase:
             payload["default_quota"][
                 "total_running_jobs"
             ] = default_quota.total_running_jobs
+        if storage_size_mb is not None:
+            payload["storage_size_mb"] = storage_size_mb
         async with self._request(
             "POST",
             f"clusters/{cluster_name}/orgs",
@@ -1382,7 +1409,7 @@ class AdminClientBase:
             raw_data = await resp.json()
             return self._parse_org_cluster(cluster_name, raw_data)
 
-    async def update_org_cluster(self, org_cluster: OrgCluster) -> OrgCluster:
+    async def update_org_cluster(self, org_cluster: OrgCluster) -> None:
         payload: dict[str, Any] = {
             "org_name": org_cluster.org_name,
             "quota": {},
@@ -1409,8 +1436,6 @@ class AdminClientBase:
             json=payload,
         ) as resp:
             resp.raise_for_status()
-            raw_data = await resp.json()
-            return self._parse_org_cluster(org_cluster.cluster_name, raw_data)
 
     async def delete_org_cluster(
         self,
@@ -1423,6 +1448,29 @@ class AdminClientBase:
         ) as resp:
             resp.raise_for_status()
 
+    async def update_org_cluster_defaults(
+        self,
+        cluster_name: str,
+        org_name: str,
+        default_quota: Quota = Quota(),
+        default_credits: Decimal | None = None,
+    ) -> OrgCluster:
+        payload: dict[str, Any] = {
+            "quota": {},
+        }
+        if default_credits:
+            payload["credits"] = str(default_credits)
+        if default_quota.total_running_jobs is not None:
+            payload["quota"]["total_running_jobs"] = default_quota.total_running_jobs
+        async with self._request(
+            "PATCH",
+            f"clusters/{cluster_name}/orgs/{org_name}/defaults",
+            json=payload,
+        ) as resp:
+            resp.raise_for_status()
+            raw_org_cluster = await resp.json()
+            return self._parse_org_cluster(cluster_name, raw_org_cluster)
+
     async def update_org_cluster_quota(
         self,
         cluster_name: str,
@@ -1821,6 +1869,7 @@ class AdminClientDummy(AdminClientABC):
         cluster_name="default",
         balance=Balance(),
         quota=Quota(),
+        storage_size_mb=1024,
     )
     DUMMY_ORG_USER = OrgUserWithInfo(
         org_name="org",
@@ -1946,9 +1995,10 @@ class AdminClientDummy(AdminClientABC):
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
         with_user_info: Literal[True],
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         org_name: str | None = None,
     ) -> ClusterUserWithInfo:
         ...
@@ -1959,9 +2009,10 @@ class AdminClientDummy(AdminClientABC):
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
         with_user_info: Literal[False] = ...,
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         org_name: str | None = None,
     ) -> ClusterUser:
         ...
@@ -1971,8 +2022,9 @@ class AdminClientDummy(AdminClientABC):
         cluster_name: str,
         user_name: str,
         role: ClusterUserRoleType,
-        quota: Quota,
-        balance: Balance,
+        *,
+        quota: Quota | None = None,
+        balance: Balance | None = None,
         with_user_info: bool = False,
         org_name: str | None = None,
     ) -> ClusterUser | ClusterUserWithInfo:
@@ -2198,6 +2250,7 @@ class AdminClientDummy(AdminClientABC):
         balance: Balance = Balance(),
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
+        storage_size_mb: int | None = None,
     ) -> OrgCluster:
         return self.DUMMY_ORG_CLUSTER
 
@@ -2211,8 +2264,8 @@ class AdminClientDummy(AdminClientABC):
     ) -> OrgCluster:
         return self.DUMMY_ORG_CLUSTER
 
-    async def update_org_cluster(self, org_cluster: OrgCluster) -> OrgCluster:
-        return self.DUMMY_ORG_CLUSTER
+    async def update_org_cluster(self, org_cluster: OrgCluster) -> None:
+        pass
 
     async def delete_org_cluster(
         self,
@@ -2221,6 +2274,15 @@ class AdminClientDummy(AdminClientABC):
     ) -> None:
         pass
 
+    async def update_org_cluster_defaults(
+        self,
+        cluster_name: str,
+        org_name: str,
+        default_quota: Quota = Quota(),
+        default_credits: Decimal | None = None,
+    ) -> OrgCluster:
+        return self.DUMMY_ORG_CLUSTER
+
     async def update_org_cluster_quota(
         self,
         cluster_name: str,
